# spectre-core

## Description
  
:loudspeaker: **This project is under active development. Contributors welcome.** :loudspeaker:  

```spectre-core``` provides an extensible, receiver-agnostic toolkit for generating radio spectrograms in real-time. It is the core Python package used by the [`spectre`](https://github.com/jcfitzpatrick12/spectre.git) program.   


## Installation
Simply call:  
```bash
pip install spectre-core
```

Alternatively, you can clone the repository in your preferred directory:  
```bash
git clone https://github.com/jcfitzpatrick12/spectre-core.git && cd spectre-core
```  

Then run:  
```
pip install -e .
```


## Contributing
This repository is in active development. If you are interested, feel free to contact  jcfitzpatrick12@gmail.com :)